pub struct Coordinate {
pub x: i32,
pub y: i32,
}Expand description
A two-dimensional point.
Fields
x: i32y: i32Implementations
Sourceimpl Coordinate
impl Coordinate
pub fn coordinate_in_direction( direction: &AbsoluteDirection, magnitude: usize, ) -> Self
pub fn move_in_direction( &mut self, direction: &AbsoluteDirection, magnitude: usize, )
Sourcepub fn is_above_row(&self, row: i32) -> bool
pub fn is_above_row(&self, row: i32) -> bool
Checks if the coordinate is above a row. If the coordinate is on the row the function returns true.
Sourcepub fn is_below_row(&self, row: i32) -> bool
pub fn is_below_row(&self, row: i32) -> bool
Checks if the coordinate is below a row. If the coordinate is on the row the function returns true.